from setuptools import setup

setup(name='udacity_distributions_rashmi',
      version='1.0',
      description='Gaussian and Binomial distributions',
      packages=['udacity_distributions_rashmi'],
      zip_safe=False)
